@@ -1,14 +1,12 @@
 package FabForce::DBDesigner4;
 
-# ABSTRACT:  Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
-
 use strict;
 use warnings;
 use Carp;
 use FabForce::DBDesigner4::XML;
 use FabForce::DBDesigner4::SQL;
 
-our $VERSION     = '0.34';
+our $VERSION     = '0.302';
 
 sub new{
   my ($class,%args) = @_;
@@ -67,6 +65,10 @@ sub getSQL{
 __END__
 
 
+=head1 NAME
+
+FabForce::DBDesigner4 - Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
+
 =head1 SYNOPSIS
 
   use FabForce::DBDesigner4;
@@ -192,8 +194,6 @@ Methods of the table-objects
   print "the primary key contains these columns:\n";
   print $_,"\n" for($table->key());
 
-=head2 column_details
-
 =head1 DEPENDENCIES
 
 This module requires XML::Twig
@@ -207,4 +207,17 @@ bugreports or comments on this module.
 
   XML::Twig and IO::File
 
+=head1 AUTHOR
+
+Renee Baecker, E<lt>module@renee-baecker.deE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2005 - 2009 by Renee Baecker
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the Artistic License version 2.0.
+
+These conditions apply for all files in this package.
+
 =cut
